@@ -25,5 +25,7 @@ mdl_ms2 <- list(n     = 100,
 # Simulate process using simuMSAR() function
 y_ms_simu <- simuMSAR(mdl_ms2)
 
-#mdl <- BootLRTest(y_ms_simu$y, p = 1, k0 = 1, k1 = 2, bootlrt_control)
-#mdl
\ No newline at end of file
+\donttest{
+  boottest <- BootLRTest(y_ms_simu$y, p = 1, k0 = 1, k1 = 2, bootlrt_control)
+  summary(boottest)
+}
\ No newline at end of file
