@@ -8,6 +8,7 @@ control = list(N = 1000,
                msvar = FALSE)
 
 # perform test with switch in mean only on Hamilton 1989 data
-#mdl_84_msmu <- CHPTest(y84, p = 4, control = control)
-#mdl_84_msmu
-
+\donttest{
+  mdl_84_msmu <- CHPTest(y84, p = 4, control = control)
+  summary(mdl_84_msmu)
+}
