@@ -18,9 +18,8 @@ mmc_control <- list(N = 99,
 
 
 # perform test on Hamilton 1989 data
-mmc_gnp84 <- DLMMCTest(y84, p = 4, control = mmc_control)
-mmc_gnp84
+\donttest{
+  mmc_gnp84 <- DLMMCTest(y84, p = 4, control = mmc_control)
+  summary(mmc_gnp84)
+}
 
-# perform test on extended data used in Carrasco, Hu & Ploberger 2014 & Dufour & Luger 2017
-mmc_gnp10 <- DLMMCTest(y10, p = 4, control = mmc_control)
-mmc_gnp10
\ No newline at end of file
